==> nextcloud-21.0.4.tgz: nextcloud/apps/encryption/l10n/nb.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Passord for gjenopprettingsnøkkel mangler",
    "Please repeat the recovery key password" : "Gjenta passord for gjenopprettingsnøkkel",
    "Repeated recovery key password does not match the provided recovery key password" : "Gjentatt passord for gjenopprettingsnøkkel stemmer ikke med oppgitt passord for gjenopprettingsnøkkel",
    "Recovery key successfully enabled" : "Gjenopprettingsnøkkel aktivert",
    "Could not enable recovery key. Please check your recovery key password!" : "Klarte ikke å aktivere gjenopprettingsnøkkel. Sjekk passordet for gjenopprettingsnøkkelen.",
    "Recovery key successfully disabled" : "Gjenopprettingsnøkkel ble deaktivert",
    "Could not disable recovery key. Please check your recovery key password!" : "Klarte ikke å deaktivere gjenopprettingsnøkkel. Sjekk passordet for gjenopprettingsnøkkelen.",
    "Missing parameters" : "Manglende parametre",
    "Please provide the old recovery password" : "Oppgi det gamle gjenopprettingspassordet",
    "Please provide a new recovery password" : "Oppgi et nytt gjenopprettingspassord",
    "Please repeat the new recovery password" : "Gjenta det nye gjenopprettingspassordet",
    "Password successfully changed." : "Passordet ble endret.",
    "Could not change the password. Maybe the old password was not correct." : "Klarte ikke å endre passordet. Kanskje gammelt passord ikke var korrekt.",
    "Recovery Key disabled" : "Gjenopprettingsnøkkel deaktivert",
    "Recovery Key enabled" : "Gjenopprettingsnøkkel aktivert",
    "Could not enable the recovery key, please try again or contact your administrator" : "Klarte ikke å aktivere gjenopprettingsnøkkelen. Prøv igjen eller kontakt administratoren.",
    "Could not update the private key password." : "Klarte ikke å oppdatere privatnøkkelpassordet.",
    "The old password was not correct, please try again." : "Det gamle passordet var feil. Prøv igjen.",
    "The current log-in password was not correct, please try again." : "Det nåværende innloggingspassordet var feil. Prøv igjen.",
    "Private key password successfully updated." : "Passord for privat nøkkel ble oppdatert.",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "Ugyldig privat nøkkel for Krypterings-appen. Oppdater passordet for din private nøkkel i dine personlige innstillinger for å gjenopprette tilgang til de krypterte filene dine.",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "Krypteringappen er aktivert, men nøklene dine er ikke satt opp. Logg ut og inn igjen.",
    "Please enable server side encryption in the admin settings in order to use the encryption module." : "Skru på kryptering på serverdelen i innstillingene for å bruke krypteringsmodulen.",
    "Encryption app is enabled and ready" : "Krypterings-appen er aktivert og klart",
    "Bad Signature" : "Feil signatur",
    "Missing Signature" : "Manglende signatur",
    "one-time password for server-side-encryption" : "engangspassord for kryptering på serverdelen",
    "Default encryption module" : "Standard krypteringsmodul",
    "Default encryption module for server-side encryption" : "Standard krypteringsmodul for kryptering på serverdelen",
    "The share will expire on %s." : "Delingen vil opphøre %s.",
    "Cheers!" : "Ha det!",
    "Hey there,<br><br>the admin enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>.<br><br>Please login to the web interface, go to the section \"basic encryption module\" of your personal settings and update your encryption password by entering this password into the \"old log-in password\" field and your current login-password.<br><br>" : "Hei,<br><br>Administratoren har skrudd på kryptering på serversiden. Filene dine er blitt kryptert med passordet <strong>%s</strong>.<br><br>Logg inn på web-grensesnittet, gå til seksjonen \"grunnleggende krypteringsmodul\" i dine personlige innstillinger og oppdater krypteringspassordet ditt ved å legge inn dette passordet i feltet \"gammelt påloggingspassord\" sammen med ditt nåværende påloggingspassord.<br><br>",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "Krypterings-appen er aktivert men nøklene dine er ikke satt opp. Logg ut og inn igjen.",
    "Encrypt the home storage" : "Krypter hjemmelageret",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "Aktivering av dette valget krypterer alle filer som er lagret på hovedlageret. Ellers vil kun filer på eksterne lagre bli kryptert.",
    "Enable recovery key" : "Aktiver gjenopprettingsnøkkel",
    "Disable recovery key" : "Deaktiver gjenopprettingsnøkkel",
    "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "Gjenopprettingsnøkkelen er en ekstra krypteringsnøkkel som brukes til å kryptere filer. Den tillater gjenoppretting av en brukers filer i tilfelle brukeren glemmer passordet sitt.",
    "Recovery key password" : "Passord for gjenopprettingsnøkkel",
    "Repeat recovery key password" : "Gjenta passord for gjenopprettingsnøkkel",
    "Change recovery key password:" : "Endre passord for gjenopprettingsnøkkel:",
    "Old recovery key password" : "Gammelt passord for gjenopprettingsnøkkel",
    "New recovery key password" : "Nytt passord for gjenopprettingsnøkkel",
    "Repeat new recovery key password" : "Gjenta nytt passord for gjenopprettingsnøkkel",
    "Change Password" : "Endre passord",
    "Basic encryption module" : "Grunnleggende krypteringsmodul",
    "Your private key password no longer matches your log-in password." : "Passordet for din private nøkkel stemmer ikke lenger med påloggingspassordet ditt.",
    "Set your old private key password to your current log-in password:" : "Sett ditt gamle passord for privat nøkkel til ditt nåværende påloggingspassord:",
    " If you don't remember your old password you can ask your administrator to recover your files." : "Hvis du ikke husker det gamle passordet ditt kan du spørre administratoren om å gjenopprette filene dine.",
    "Old log-in password" : "Gammelt påloggingspassord",
    "Current log-in password" : "Nåværende påloggingspassord",
    "Update Private Key Password" : "Oppdater passord for privat nøkkel",
    "Enable password recovery:" : "Aktiver gjenoppretting av passord:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Aktivering av dette valget tillater deg å gjenerobre tilgang til dine krypterte filer i tilfelle du mister passordet ditt.",
    "Enabled" : "Aktivert",
    "Disabled" : "Inaktiv",
    "Can not decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Kan ikke dekryptere denne filen. Dette er sannsynligvis en delt fil. Spør eieren av filen om å dele den med deg på nytt.",
    "Can not read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Kan ikke lese denne filen, som sannsynligvis er en delt fil. Be eieren av filen om å dele den med deg på nytt.",
    "Hey there,\n\nthe admin enabled server-side-encryption. Your files were encrypted using the password '%s'.\n\nPlease login to the web interface, go to the section 'basic encryption module' of your personal settings and update your encryption password by entering this password into the 'old log-in password' field and your current login-password.\n\n" : "Hei,\n\nAdministratoren har aktivert kryptering på serverdelen. Filene dine har blitt kryptert med passordet '%s'.\n\nlogg inn på web-grensesnittet, gå til seksjonen 'grunnleggende krypteringsmodul' i dine personlige innstillinger og oppdater krypteringspassordet ditt ved å legge inn dette passordet i feltet 'gammelt påloggingspassord' sammen med ditt nåværende påloggingspassord.\n"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-21.0.8p0.tgz: nextcloud/apps/encryption/l10n/nb.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Passord for gjenopprettingsnøkkel mangler",
    "Please repeat the recovery key password" : "Gjenta passord for gjenopprettingsnøkkel",
    "Repeated recovery key password does not match the provided recovery key password" : "Gjentatt passord for gjenopprettingsnøkkel stemmer ikke med oppgitt passord for gjenopprettingsnøkkel",
    "Recovery key successfully enabled" : "Gjenopprettingsnøkkel aktivert",
    "Could not enable recovery key. Please check your recovery key password!" : "Klarte ikke å aktivere gjenopprettingsnøkkel. Sjekk passordet for gjenopprettingsnøkkelen.",
    "Recovery key successfully disabled" : "Gjenopprettingsnøkkel ble deaktivert",
    "Could not disable recovery key. Please check your recovery key password!" : "Klarte ikke å deaktivere gjenopprettingsnøkkel. Sjekk passordet for gjenopprettingsnøkkelen.",
    "Missing parameters" : "Manglende parametre",
    "Please provide the old recovery password" : "Oppgi det gamle gjenopprettingspassordet",
    "Please provide a new recovery password" : "Oppgi et nytt gjenopprettingspassord",
    "Please repeat the new recovery password" : "Gjenta det nye gjenopprettingspassordet",
    "Password successfully changed." : "Passordet ble endret.",
    "Could not change the password. Maybe the old password was not correct." : "Klarte ikke å endre passordet. Kanskje gammelt passord ikke var korrekt.",
    "Recovery Key disabled" : "Gjenopprettingsnøkkel deaktivert",
    "Recovery Key enabled" : "Gjenopprettingsnøkkel aktivert",
    "Could not enable the recovery key, please try again or contact your administrator" : "Klarte ikke å aktivere gjenopprettingsnøkkelen. Prøv igjen eller kontakt administratoren.",
    "Could not update the private key password." : "Klarte ikke å oppdatere privatnøkkelpassordet.",
    "The old password was not correct, please try again." : "Det gamle passordet var feil. Prøv igjen.",
    "The current log-in password was not correct, please try again." : "Det nåværende innloggingspassordet var feil. Prøv igjen.",
    "Private key password successfully updated." : "Passord for privat nøkkel ble oppdatert.",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "Ugyldig privat nøkkel for Krypterings-appen. Oppdater passordet for din private nøkkel i dine personlige innstillinger for å gjenopprette tilgang til de krypterte filene dine.",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "Krypteringappen er aktivert, men nøklene dine er ikke satt opp. Logg ut og inn igjen.",
    "Please enable server side encryption in the admin settings in order to use the encryption module." : "Skru på kryptering på serverdelen i innstillingene for å bruke krypteringsmodulen.",
    "Encryption app is enabled and ready" : "Krypterings-appen er aktivert og klart",
    "Bad Signature" : "Feil signatur",
    "Missing Signature" : "Manglende signatur",
    "one-time password for server-side-encryption" : "engangspassord for kryptering på serverdelen",
    "Default encryption module" : "Standard krypteringsmodul",
    "Default encryption module for server-side encryption" : "Standard krypteringsmodul for kryptering på serverdelen",
    "The share will expire on %s." : "Delingen vil opphøre %s.",
    "Cheers!" : "Ha det!",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "Krypterings-appen er aktivert men nøklene dine er ikke satt opp. Logg ut og inn igjen.",
    "Encrypt the home storage" : "Krypter hjemmelageret",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "Aktivering av dette valget krypterer alle filer som er lagret på hovedlageret. Ellers vil kun filer på eksterne lagre bli kryptert.",
    "Enable recovery key" : "Aktiver gjenopprettingsnøkkel",
    "Disable recovery key" : "Deaktiver gjenopprettingsnøkkel",
    "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "Gjenopprettingsnøkkelen er en ekstra krypteringsnøkkel som brukes til å kryptere filer. Den tillater gjenoppretting av en brukers filer i tilfelle brukeren glemmer passordet sitt.",
    "Recovery key password" : "Passord for gjenopprettingsnøkkel",
    "Repeat recovery key password" : "Gjenta passord for gjenopprettingsnøkkel",
    "Change recovery key password:" : "Endre passord for gjenopprettingsnøkkel:",
    "Old recovery key password" : "Gammelt passord for gjenopprettingsnøkkel",
    "New recovery key password" : "Nytt passord for gjenopprettingsnøkkel",
    "Repeat new recovery key password" : "Gjenta nytt passord for gjenopprettingsnøkkel",
    "Change Password" : "Endre passord",
    "Basic encryption module" : "Grunnleggende krypteringsmodul",
    "Your private key password no longer matches your log-in password." : "Passordet for din private nøkkel stemmer ikke lenger med påloggingspassordet ditt.",
    "Set your old private key password to your current log-in password:" : "Sett ditt gamle passord for privat nøkkel til ditt nåværende påloggingspassord:",
    " If you don't remember your old password you can ask your administrator to recover your files." : "Hvis du ikke husker det gamle passordet ditt kan du spørre administratoren om å gjenopprette filene dine.",
    "Old log-in password" : "Gammelt påloggingspassord",
    "Current log-in password" : "Nåværende påloggingspassord",
    "Update Private Key Password" : "Oppdater passord for privat nøkkel",
    "Enable password recovery:" : "Aktiver gjenoppretting av passord:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Aktivering av dette valget tillater deg å gjenerobre tilgang til dine krypterte filer i tilfelle du mister passordet ditt.",
    "Enabled" : "Aktivert",
    "Disabled" : "Inaktiv",
    "Can not decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Kan ikke dekryptere denne filen. Dette er sannsynligvis en delt fil. Spør eieren av filen om å dele den med deg på nytt.",
    "Can not read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Kan ikke lese denne filen, som sannsynligvis er en delt fil. Be eieren av filen om å dele den med deg på nytt.",
    "Hey there,\n\nthe admin enabled server-side-encryption. Your files were encrypted using the password '%s'.\n\nPlease login to the web interface, go to the section 'basic encryption module' of your personal settings and update your encryption password by entering this password into the 'old log-in password' field and your current login-password.\n\n" : "Hei,\n\nAdministratoren har aktivert kryptering på serverdelen. Filene dine har blitt kryptert med passordet '%s'.\n\nlogg inn på web-grensesnittet, gå til seksjonen 'grunnleggende krypteringsmodul' i dine personlige innstillinger og oppdater krypteringspassordet ditt ved å legge inn dette passordet i feltet 'gammelt påloggingspassord' sammen med ditt nåværende påloggingspassord.\n",
    "Hey there,<br><br>the admin enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>.<br><br>Please login to the web interface, go to the section \"basic encryption module\" of your personal settings and update your encryption password by entering this password into the \"old log-in password\" field and your current login-password.<br><br>" : "Hei,<br><br>Administratoren har skrudd på kryptering på serversiden. Filene dine er blitt kryptert med passordet <strong>%s</strong>.<br><br>Logg inn på web-grensesnittet, gå til seksjonen \"grunnleggende krypteringsmodul\" i dine personlige innstillinger og oppdater krypteringspassordet ditt ved å legge inn dette passordet i feltet \"gammelt påloggingspassord\" sammen med ditt nåværende påloggingspassord.<br><br>"
},
"nplurals=2; plural=(n != 1);");
